@@ -82,7 +82,7 @@ SENSOR_INFOS: Dict[int, Tuple[str, str, int]] = {
         7 * 60,  # 7 min
     ),
     0x03: (
-        "MA10200/250",
+        "MA10200",
         "Temperature/Humidity",
         7 * 60,  # 7 min
     ),
@@ -128,7 +128,7 @@ SENSOR_INFOS: Dict[int, Tuple[str, str, int]] = {
         7 * 60,  # 7 min
     ),
     0x0E: (
-        "TFA30.3312.02",
+        "MA10250",
         "Professional Thermo/Hygro sensor",
         3 * 60 + 30,  # 3.5 min
     ),
@@ -616,9 +616,9 @@ class Sensor:
         self._name = name
 
         self._counter = -1
-        self._low_battery = False
-        self._by_event = False
-        self._timestamp = time.time()
+        self._low_battery: Optional[bool] = None
+        self._by_event: Optional[bool] = None
+        self._timestamp: Optional[float] = None
         self._last_update: Optional[bytes] = None
 
         self._name = name
@@ -740,9 +740,13 @@ class Sensor:
         result: str = ("%s (id: %s, battery %s, last %s: %s)") % (
             self._name,
             self._id,
-            "low" if self._low_battery else "good",
+            "unknown"
+            if self._low_battery is None
+            else "low"
+            if self._low_battery
+            else "good",
             "event" if self._by_event else "seen",
-            time.ctime(self._timestamp),
+            time.ctime(self._timestamp) if self._timestamp is not None else "unknown",
         )
         for measurement in self._measurements:
             result += "\n" + str(measurement)
@@ -754,9 +758,15 @@ class Sensor:
 
         result: str = ("id: %s (battery %s, last %s: %s)") % (
             self._id,
-            "low" if self._low_battery else "good",
+            "unknown"
+            if self._low_battery is None
+            else "low"
+            if self._low_battery
+            else "good",
             "event" if self._by_event else "seen",
-            time.strftime("%Y-%m-%d %H:%M:%S", timestamp_struct),
+            time.strftime("%Y-%m-%d %H:%M:%S", timestamp_struct)
+            if self._timestamp is not None
+            else "unknown",
         )
         for measurement in self._measurements:
             result += "\n" + str(measurement)
@@ -849,6 +859,8 @@ class Sensor:
             self[0]._set_boolean(packet[14:16], 0x8000)
             self[1]._set_door_window_time_span(packet[14:22])
         elif self._type_id == 0x11:
+            self[0]._set_temperature(packet[26:28], packet[42:44])
+            self[1]._set_humidity(packet[29], packet[45])
             self[2]._set_temperature(packet[14:16], packet[30:32])
             self[3]._set_humidity(packet[17], packet[33])
             self[4]._set_temperature(packet[18:20], packet[34:36])
@@ -910,15 +922,15 @@ class Sensor:
         return self._counter
 
     @property
-    def low_battery(self) -> bool:
+    def low_battery(self) -> Optional[bool]:
         return self._low_battery
 
     @property
-    def by_event(self) -> bool:
+    def by_event(self) -> Optional[bool]:
         return self._by_event
 
     @property
-    def timestamp(self) -> float:
+    def timestamp(self) -> Optional[float]:
         return self._timestamp
 
     @property
